from setuptools import setup

setup(name='weasl',
    version='0.1',
    description='weakly supervised active learning framework',
    url='https://github.com/njpataki/weasl',
    author='Nicholas Pataki',
    author_email='njpatakI@gmail.com',
    license='MIT',
    packages=['weasl'],
    zip_safe=False)
